@@ -1,12 +1,10 @@
 // This file is licensed under the terms of Apache-2.0 License.
-#![feature(test)]
+
 #![allow(clippy::tabs_in_doc_comments)]
 
 mod args;
-/// Contains the syntactic elements of a command.
+/// Syntactic elements of a [Command].
 pub mod ast;
-#[cfg(test)]
-mod benches;
 mod compiler;
 mod engine;
 /// Various errors used by the [Error] type.
@@ -17,15 +15,22 @@ mod tests;
 
 use std::fmt;
 
-pub use args::Args;
+pub use args::{
+	Args,
+	Match,
+};
 pub use compiler::Command;
-pub use engine::Match;
 use errors::*;
 
+/// Every possible error produced by this crate.
 #[derive(Debug, Eq, PartialEq, Clone)]
 pub enum Error {
+	/// Returned when the command fails to parse.
 	Syntax(SyntaxError),
+	/// Returned when a command has an invalid filter.
 	Filter(FilterError),
+	/// Returned when a command fails to compile. This usually means there is no
+	/// way to get linear time matching.
 	Rule(RuleError),
 }
 
